@@ -31,10 +31,9 @@ import pyrecipe_utils
 import base64
 
 import osso
-osso_c = osso.Context("pyrecipe_service", "0.2", False)
+osso_c = osso.Context("org.maemo.pyrecipe", "0.3", False)
 
-#from portrait import FremantleAutoRotation
-#FremantleAutoRotation()
+from portrait import FremantleRotation
 
 fhsize = gtk.HILDON_SIZE_FINGER_HEIGHT
 horbtn = hildon.BUTTON_ARRANGEMENT_HORIZONTAL
@@ -52,7 +51,7 @@ logfile = configdir + 'log.txt'
 import sys
 runningpath = sys.path[0]
 
-if '/usr/share' in runningpath:
+if '/opt' in runningpath:
     locally = False
 else:
     locally = True
@@ -77,7 +76,7 @@ else:
 if locally:
     imgdir = 'pixmaps/'
 else:
-    appdir = '/usr/share/pyrecipe/'
+    appdir = '/opt/pyrecipe/'
     imgdir = appdir + 'pixmaps/'
 
 logger = logging.getLogger('pyrecipe')
@@ -112,6 +111,7 @@ class MainWindow:
         self.window.connect("destroy", gtk.main_quit)
         self.program.add_window(self.window)
 
+        self.rotation = FremantleRotation('Pyrecipe', None, "0.3", 0)
         self.initialize_vars()
 
         self.fontsize = 15
@@ -127,6 +127,7 @@ class MainWindow:
 
         self.window.show_all()
 
+
     def initialize_vars(self):
         self.title = ''
         self.cat = 'Dessert'
@@ -611,6 +612,14 @@ class MainWindow:
 
         return lista[0][6]
 
+    def is_portrait(self):
+        width = gtk.gdk.screen_width()
+        height = gtk.gdk.screen_height()
+        if width > height:
+            return False
+        else:
+            return True
+
     def recipe_edit_screen(self, widget, kind):
         selection = self.recipelist_tv.get_selection()
         if kind == 'edit':
@@ -630,39 +639,37 @@ class MainWindow:
         win = hildon.StackableWindow()
         win.set_title(titlewin)
 
-        vbox = gtk.VBox()
+        menu = self.make_edit_menu(kind)
+        win.set_app_menu(menu)
+
+        win.get_screen().connect("size-changed", self.orientation_changed)
+
 
         self.entitle = hildon.Entry(fhsize)
         self.entitle.set_placeholder("Title")
         self.entitle.set_text(self.title)
         self.entitle.connect("changed", self.change_title)
 
-        hbox = gtk.HBox()
-
-        vbox1 = gtk.VBox()
-
-        self.cat_btn = hildon.PickerButton(fhsize, horbtn)
+        self.catbtn = hildon.PickerButton(fhsize, horbtn)
         data = ["Appetizer", "Breakfast", "Brunch", "Dessert", "Entree",
                 "Salad", "Sauce", "Snack", "Soup"]
         selector = self.create_selector(data, True)
-        self.cat_btn.set_selector(selector)
-        self.cat_btn.set_title("Category")
-        self.cat_btn.set_value(self.cat)
-        self.cat_btn.connect("value-changed", self.change_cat)
-        vbox1.pack_start(self.cat_btn, True, True, 0)
+        self.catbtn.set_selector(selector)
+        self.catbtn.set_title("Category")
+        self.catbtn.set_value(self.cat)
+        self.catbtn.connect("value-changed", self.change_cat)
 
-        self.servings_btn = hildon.PickerButton(fhsize, horbtn)
+        self.servingsbtn = hildon.PickerButton(fhsize, horbtn)
         data = []
         for i in range(1, 13):
             data.append(str(i))
         selector = self.create_selector(data, True)
-        self.servings_btn.set_selector(selector)
-        self.servings_btn.set_title("Servings")
-        self.servings_btn.set_value(self.servings)
-        self.servings_btn.connect("value-changed", self.change_servings)
-        vbox1.pack_start(self.servings_btn, True, True, 0)
+        self.servingsbtn.set_selector(selector)
+        self.servingsbtn.set_title("Servings")
+        self.servingsbtn.set_value(self.servings)
+        self.servingsbtn.connect("value-changed", self.change_servings)
 
-        self.preptime_btn = hildon.PickerButton(fhsize, horbtn)
+        self.preptimebtn = hildon.PickerButton(fhsize, horbtn)
         tmtime = ["10", "20", "30", "40", "50", "60", "70", "80", "90", "100",
                     "110", "120", "130", "140", "150"]
         minu = " minutes"
@@ -670,31 +677,26 @@ class MainWindow:
         for i in tmtime:
             data.append(i+minu)
         selector = self.create_selector(data, True)
-        self.preptime_btn.set_selector(selector)
-        self.preptime_btn.set_title("Preparation time")
-        self.preptime_btn.set_value(self.preptime)
-        self.preptime_btn.connect("value-changed", self.change_preptime)
-        vbox1.pack_start(self.preptime_btn, True, True, 0)
+        self.preptimebtn.set_selector(selector)
+        self.preptimebtn.set_title("Preparation time")
+        self.preptimebtn.set_value(self.preptime)
+        self.preptimebtn.connect("value-changed", self.change_preptime)
 
-        self.cooktime_btn = hildon.PickerButton(fhsize, horbtn)
+        self.cooktimebtn = hildon.PickerButton(fhsize, horbtn)
         data = []
         for i in tmtime:
             data.append(i+minu)
         selector = self.create_selector(data, True)
-        self.cooktime_btn.set_selector(selector)
-        self.cooktime_btn.set_title("Cooking time")
-        self.cooktime_btn.set_value(self.cooktime)
-        self.cooktime_btn.connect("value-changed", self.change_cooktime)
-        vbox1.pack_start(self.cooktime_btn, True, True, 0)
+        self.cooktimebtn.set_selector(selector)
+        self.cooktimebtn.set_title("Cooking time")
+        self.cooktimebtn.set_value(self.cooktime)
+        self.cooktimebtn.connect("value-changed", self.change_cooktime)
 
-        hbox.pack_start(vbox1, True, True, 0)
 
-        vbox1 = gtk.VBox()
+        self.setbutton = hildon.Button(fhsize, horbtn)
+        self.setbutton.set_label('Set image')
+        self.setbutton.connect("clicked", self.select_image)
 
-        hbox1 = gtk.HBox()
-        button = hildon.Button(fhsize, horbtn)
-        button.set_label('Set image')
-        button.connect("clicked", self.select_image)
         self.image = gtk.Image()
         if self.imagefile:
             pixbuf = self.base64_to_pixbuf(self.imagefile)
@@ -703,31 +705,169 @@ class MainWindow:
             missing_img = gtk.gdk.pixbuf_new_from_file(imgdir + 'image.png')
             self.image.set_from_pixbuf(missing_img)
 
-        hbox1.pack_start(button, True, True, 0)
+        self.clearbutton = hildon.Button(fhsize, horbtn)
+        self.clearbutton.set_label('Clear image')
+        self.clearbutton.connect("clicked", self.clear_image)
 
-        button = hildon.Button(fhsize, horbtn)
-        img = gtk.Image()
-        img.set_from_file(imgdir + "clear.png")
-        button.set_image(img)
-        button.connect("clicked", self.clear_image)
-        hbox1.pack_start(button, True, True, 0)
+        self.mainbox = gtk.VBox()
+        self.mainbox.pack_start(self.entitle, False, False, 0)
+
+        if self.is_portrait():
+            self.mainbox.pack_start(self.catbtn, False, False, 0)
+            self.mainbox.pack_start(self.servingsbtn, False, False, 0)
+            self.mainbox.pack_start(self.preptimebtn, False, False, 0)
+            self.mainbox.pack_start(self.cooktimebtn, False, False, 0)
+            self.imghbox = gtk.HBox()
+            self.imghbox.pack_start(self.setbutton, True, True, 0)
+            self.imghbox.pack_start(self.clearbutton, True, True, 0)
+            self.mainbox.pack_start(self.imghbox, False, False, 0)
+            self.mainbox.pack_start(self.image, True, True, 0)
+
+        else:
+            self.hbox1 = gtk.HBox()
+            self.hbox1.set_homogeneous(True)
+            self.hbox1.pack_start(self.catbtn, True, True, 0)
+            self.hbox1.pack_start(self.servingsbtn, True, True, 0)
+            self.mainbox.pack_start(self.hbox1, False, False, 0)
+
+            self.hbox2 = gtk.HBox()
+            self.hbox2.set_homogeneous(True)
+            self.hbox2.pack_start(self.preptimebtn, True, True, 0)
+            self.hbox2.pack_start(self.cooktimebtn, True, True, 0)
+            self.mainbox.pack_start(self.hbox2, False, False, 0)
 
 
-        vbox1.pack_start(hbox1, False, False, 0)
-        vbox1.pack_start(self.image, True, True, 0)
+            self.imghbox = gtk.HBox()
+            self.vbox1 = gtk.VBox()
+            self.vbox1.pack_start(gtk.VSeparator(), True, True, 0)
+            self.vbox1.pack_start(self.setbutton, False, False, 0)
+            self.vbox1.pack_start(self.clearbutton, False, False, 0)
+            self.vbox1.pack_start(gtk.VSeparator(), True, True, 0)
+            self.imghbox.pack_start(self.vbox1, False, False, 0)
 
-        hbox.pack_start(vbox1, True, True, 0)
+            self.imghbox.pack_start(self.image, True, True, 0)
+            self.mainbox.pack_start(self.imghbox, True, True, 0)
 
-        toolbar = self.edittoolbar(kind)
 
-        vbox.pack_start(self.entitle, False, False, 0)
-        vbox.pack_start(hbox, True, True, 0)
-        vbox.pack_start(toolbar, False, False, 0)
-
-        win.add(vbox)
+        #self.mainbox.pack_start(toolbar, False, False, 0)
 
+        win.add(self.mainbox)
         win.show_all()
 
+    #FIXME: there's a bug that is hitted so:
+    # 1) Start application in landscape, Edit a recipe
+    # 2) Go to portrait, go to landscape
+    # 3) Go back to initial list
+    # 4) Put to portrait
+    # 5) Edit a recipe in portrait
+    # 6) Go to landscape
+    def orientation_changed(self, screen):
+        if not self.image.get_parent_window().is_visible():
+            print 'not in the right screen, doing nothing'
+            return
+
+        try:
+            if self.is_portrait():
+                print 'from landscape to portrait'
+
+                #unparent the widgets
+                self.hbox1.remove(self.catbtn)
+                self.hbox1.remove(self.servingsbtn)
+                self.hbox2.remove(self.preptimebtn)
+                self.hbox2.remove(self.cooktimebtn)
+
+                self.mainbox.pack_start(self.catbtn, False, False, 0)
+                self.mainbox.reorder_child(self.catbtn, 1)
+                self.mainbox.pack_start(self.servingsbtn, False, False, 0)
+                self.mainbox.reorder_child(self.servingsbtn, 2)
+                self.mainbox.pack_start(self.preptimebtn, False, False, 0)
+                self.mainbox.reorder_child(self.preptimebtn, 3)
+                self.mainbox.pack_start(self.cooktimebtn, False, False, 0)
+                self.mainbox.reorder_child(self.cooktimebtn, 4)
+
+                self.vbox1.remove(self.setbutton)
+                self.vbox1.remove(self.clearbutton)
+                self.imghbox.remove(self.vbox1)
+                self.imghbox.remove(self.image)
+                self.mainbox.remove(self.imghbox)
+
+                self.imghbox.pack_start(self.setbutton, True, True, 0)
+                self.imghbox.pack_start(self.clearbutton, True, True, 0)
+
+                self.mainbox.pack_start(self.imghbox, False, False, 0)
+                self.mainbox.reorder_child(self.imghbox, 5)
+
+                self.mainbox.pack_start(self.image, True, True, 0)
+                self.mainbox.reorder_child(self.image, 6)
+            else:
+                print 'from portrait to landscape'
+
+                self.mainbox.remove(self.catbtn)
+                self.mainbox.remove(self.servingsbtn)
+                self.mainbox.remove(self.preptimebtn)
+                self.mainbox.remove(self.cooktimebtn)
+                self.mainbox.remove(self.image)
+                self.mainbox.remove(self.imghbox)
+                self.imghbox.remove(self.setbutton)
+                self.imghbox.remove(self.clearbutton)
+
+                try: #if hbox1/hbox2 exists, just packing the widgets
+                    self.hbox1.pack_start(self.catbtn, True, True, 0)
+                    self.hbox1.reorder_child(self.catbtn, 0)
+                    self.hbox1.pack_start(self.servingsbtn, True, True, 0)
+                    self.hbox1.reorder_child(self.servingsbtn, 1)
+
+                    self.hbox2.pack_start(self.preptimebtn, True, True, 0)
+                    self.hbox2.reorder_child(self.preptimebtn, 0)
+                    self.hbox2.pack_start(self.cooktimebtn, True, True, 0)
+                    self.hbox2.reorder_child(self.cooktimebtn, 1)
+
+                    self.vbox1.pack_start(self.setbutton, False, False, 0)
+                    self.vbox1.reorder_child(self.setbutton, 0)
+
+                    self.vbox1.pack_start(self.clearbutton, False, False, 0)
+                    self.vbox1.reorder_child(self.clearbutton, 1)
+
+                    self.imghbox.pack_start(self.vbox1, False, False, 0)
+                    self.imghbox.reorder_child(self.vbox1, 0)
+
+                    self.imghbox.pack_start(self.image, True, True, 0)
+                    self.imghbox.reorder_child(self.image, 1)
+
+                    self.mainbox.pack_start(self.imghbox, True, True, 0)
+                    self.mainbox.reorder_child(self.imghbox, 3)
+                except:
+                    self.hbox1 = gtk.HBox()
+                    self.hbox1.set_homogeneous(True)
+                    self.hbox1.pack_start(self.catbtn, True, True, 0)
+                    self.hbox1.pack_start(self.servingsbtn, True, True, 0)
+                    self.mainbox.pack_start(self.hbox1, False, False, 0)
+                    self.mainbox.reorder_child(self.hbox1, 1)
+
+                    self.hbox2 = gtk.HBox()
+                    self.hbox2.set_homogeneous(True)
+                    self.hbox2.pack_start(self.preptimebtn, True, True, 0)
+                    self.hbox2.pack_start(self.cooktimebtn, True, True, 0)
+                    self.mainbox.pack_start(self.hbox2, False, False, 0)
+                    self.mainbox.reorder_child(self.hbox2, 2)
+
+                    self.vbox1 = gtk.VBox()
+                    self.vbox1.pack_start(gtk.VSeparator(), True, True, 0)
+                    self.vbox1.pack_start(self.setbutton, False, False, 0)
+                    self.vbox1.pack_start(self.clearbutton, False, False, 0)
+                    self.vbox1.pack_start(gtk.VSeparator(), True, True, 0)
+                    self.imghbox.pack_start(self.vbox1, False, False, 0)
+
+                    self.imghbox.pack_start(self.image, True, True, 0)
+
+                    self.mainbox.pack_start(self.imghbox, True, True, 0)
+                    self.mainbox.reorder_child(self.imghbox, 3)
+
+                    self.mainbox.show_all()
+
+        except:
+            print 'it isnt the new/edit recipe screen'
+
     def clear_image(self, widget):
         self.imagefile = ""
         missing_img = gtk.gdk.pixbuf_new_from_file(imgdir + 'image.png')
@@ -748,42 +888,31 @@ class MainWindow:
     def change_cooktime(self, button):
         self.cooktime = button.get_value()
 
-    def edittoolbar(self, kind):
-        hbox = gtk.HBox()
+    def make_edit_menu(self, kind):
+        menu = hildon.AppMenu()
 
-        button = hildon.Button(fhsize, horbtn)
-        #button.set_label("New")
-        img = gtk.Image()
-        img.set_from_file(imgdir + "new.png")
-        button.set_image(img)
+        button = gtk.Button("New")
         button.connect("clicked", self.clear_recipe)
-        hbox.pack_start(button, True, True, 0)
+        menu.append(button)
 
-        button = hildon.Button(fhsize, horbtn)
-        #button.set_label("Save")
-        img = gtk.Image()
-        img.set_from_file(imgdir + "save.png")
-        button.set_image(img)
+        button = gtk.Button("Save")
         button.connect("clicked", self.save_recipe, kind)
-        hbox.pack_start(button, True, True, 0)
+        menu.append(button)
 
-        button = hildon.Button(fhsize, horbtn)
-        button.set_label("Instructions")
+        button = gtk.Button("Instructions")
         button.connect("clicked", self.edit_instructions, kind)
-        hbox.pack_start(button, True, True, 0)
+        menu.append(button)
 
-        button = hildon.Button(fhsize, horbtn)
-        button.set_label("Ingredients")
+        button = gtk.Button("Ingredients")
         button.connect("clicked", self.edit_ingredients, kind)
-        hbox.pack_start(button, True, True, 0)
+        menu.append(button)
 
-        button = hildon.Button(fhsize, horbtn)
-        button.set_label("Notes")
+        button = gtk.Button("Notes")
         button.connect("clicked", self.edit_notes, kind)
-        hbox.pack_start(button, True, True, 0)
-
-        return hbox
+        menu.append(button)
 
+        menu.show_all()
+        return menu
 
     #Save the edited recipe
     def save_recipe(self, widget, kind):
@@ -927,10 +1056,10 @@ class MainWindow:
                 self.initialize_vars()
 
                 self.entitle.set_text(self.title)
-                self.cat_btn.set_value(self.cat)
-                self.preptime_btn.set_value(self.preptime)
-                self.cooktime_btn.set_value(self.cooktime)
-                self.servings_btn.set_value(self.servings)
+                self.catbtn.set_value(self.cat)
+                self.preptimebtn.set_value(self.preptime)
+                self.cooktimebtn.set_value(self.cooktime)
+                self.servingsbtn.set_value(self.servings)
 
                 missing_img = gtk.gdk.pixbuf_new_from_file(imgdir + 'image.png')
                 self.image.set_from_pixbuf(missing_img)
@@ -1380,17 +1509,17 @@ class MainWindow:
         filename = pyrecipe_utils.show_filechooser_dialog(self.window, 'open',
                     'Import recipe ', '', '', '')
 
-        winprogind(self.window, 1)
-        thread.start_new_thread(self._do_import, (filename, widget))
-
-
-    def _do_import(self, filename, widget):
         if filename == None:
             print 'No importing recipe.'
             return None
-
         else:
-            file_ext = os.path.splitext(filename)[1]
+
+            winprogind(self.window, 1)
+            thread.start_new_thread(self._do_import, (filename, widget))
+
+
+    def _do_import(self, filename, widget):
+        file_ext = os.path.splitext(filename)[1]
 
         krecipes_ext = ['.kreml', '.kre']
         gourmet_ext = ['.grmt', '.xml']
@@ -1658,7 +1787,7 @@ class About:
 
         self.abdialog.destroy()
 
-        iface.load_url(url)
+        iface.open_new_window(url)
 
     def show_info(self, widget, kind):
         if kind == 'license':
