@@ -49,6 +49,14 @@ def get_recipe_list(sqlite_conn):
 
     return recipe_list
 
+def is_portrait():
+    width = gtk.gdk.screen_width()
+    height = gtk.gdk.screen_height()
+    if width > height:
+        return False
+    else:
+        return True
+
 #Show the hildon.filechooser dialog to open/save a file.
 def show_filechooser_dialog(window, action, title, name, format, EXT):
     if action == 'open':
@@ -60,6 +68,10 @@ def show_filechooser_dialog(window, action, title, name, format, EXT):
     file_dialog = hildon.FileChooserDialog(window, action, m)
     file_dialog.set_title(title + format)
 
+    portrait = is_portrait()
+    if portrait:
+        hildon.hildon_gtk_window_set_portrait_flags(file_dialog, 1)
+
     file_dialog.set_current_name(name)
     HOME = os.path.expanduser("~")
 
