@@ -3,6 +3,7 @@ import gtk
 import hildon
 import gobject
 import pyrecipe_utils
+from portrait import FremantleRotation
 
 fhsize = gtk.HILDON_SIZE_FINGER_HEIGHT
 horbtn = hildon.BUTTON_ARRANGEMENT_HORIZONTAL
@@ -13,13 +14,14 @@ autosize = gtk.HILDON_SIZE_AUTO_HEIGHT
 class ShopGui():
     def __init__(self, imagesdir, ings):
         self.window = hildon.Window()
-        hildon.hildon_gtk_window_set_portrait_flags(self.window,
-                                                hildon.PORTRAIT_MODE_SUPPORT)
+
+        FremantleRotation("Pyrecipe", self.window, '0.3', 0)
+
         self.window.set_default_size(800, 480)
         self.window.set_title('Pyrecipe - Shopping List')
         self.window.connect("delete-event", self.hide_window)
-        screen = gtk.gdk.screen_get_default()
-        screen.connect("size-changed", self.orientation_changed)
+        #screen = gtk.gdk.screen_get_default()
+        #screen.connect("size-changed", self.orientation_changed)
 
         menu = hildon.AppMenu()
         button = gtk.Button("Open")
@@ -35,12 +37,11 @@ class ShopGui():
 
         portrait = self.is_portrait()
 
+        hbox = gtk.VBox()
+
         if portrait:
-            hbox = gtk.VBox()
             hildon.hildon_gtk_window_set_portrait_flags(self.window,
                                                 hildon.PORTRAIT_MODE_REQUEST)
-        else:
-            hbox = gtk.HBox()
 
         parea = hildon.PannableArea()
         parea.set_property("mov-mode", hildon.MOVEMENT_MODE_BOTH)
@@ -57,14 +58,11 @@ class ShopGui():
 
         hbox.pack_start(parea, True, True, 0)
 
-        if portrait:
-            vbox = gtk.HBox()
-        else:
-            vbox = gtk.VBox()
+        vbox = gtk.HBox()
 
         vbox.set_homogeneous(True)
 
-        button = hildon.Button(autosize, horbtn)
+        button = hildon.Button(fhsize, horbtn)
         img = gtk.Image()
         img.set_from_file(imagesdir + 'add.png')
         button.set_image(img)
@@ -72,28 +70,28 @@ class ShopGui():
                         False, "")
         vbox.pack_start(button, True, True, 0)
 
-        button = hildon.Button(autosize, horbtn)
+        button = hildon.Button(fhsize, horbtn)
         img = gtk.Image()
         img.set_from_file(imagesdir + 'edit.png')
         button.set_image(img)
         button.connect('clicked', self.edit_one_item)
         vbox.pack_start(button, True, True, 0)
 
-        button = hildon.Button(autosize, horbtn)
+        button = hildon.Button(fhsize, horbtn)
         img = gtk.Image()
         img.set_from_file(imagesdir + 'remove.png')
         button.set_image(img)
         button.connect('clicked', self.remove_item)
         vbox.pack_start(button, True, True, 0)
 
-        button = hildon.Button(autosize, horbtn)
+        button = hildon.Button(fhsize, horbtn)
         img = gtk.Image()
         img.set_from_file(imagesdir + 'clear.png')
         button.set_image(img)
         button.connect('clicked', self.clear_shoplist)
         vbox.pack_start(button, True, True, 0)
 
-        button = hildon.Button(autosize, horbtn)
+        button = hildon.Button(fhsize, horbtn)
         img = gtk.Image()
         img.set_from_file(imagesdir + 'mark.png')
         button.set_image(img)
@@ -105,8 +103,10 @@ class ShopGui():
         self.window.add(hbox)
         self.window.show_all()
 
-    def orientation_changed(self, widget):
-        print 'orientation changed'
+   # def orientation_changed(self, widget):
+        #portrait = self.is_portrait()
+        #print 'portrait:', portrait
+        #TODO: rearrange los widgets???'
 
     def is_portrait(self):
         width = gtk.gdk.screen_width()
